package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````4!8``#0````XE````````#0`(``(
M`"@`'0`<``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````D(X`
M`)".```%`````!````$```#8C@``V)X``-B>``!D`@``K`(```8`````$```
M`@```.R.``#LG@``[)X``.````#@````!@````0````$````3`$``$P!``!,
M`0``+````"P````$````!````%#E=&0LA@``+(8``"R&```T`0``-`$```0`
M```$````4N5T9-B.``#8G@``V)X``"@!```H`0``!`````$````O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```'````!`````$```!.971"4T0``,"OTC4$````
M!`````,```!085@``````&$```!F```````````````K````"P``````````
M````,P````P````\`````````"H``````````0```$<```!>`````````!L`
M``!&````!````!H````1````%P```#X```!3````6@````````!2````.```
M`%4``````````````&(```!D````*````%$```!4````/P```&$```!9````
M0`````````!#````'0```#````!8````(0```"4`````````!0```$D`````
M````"0```"<```!E````5P```$4````T````2@```&,`````````7```````
M```5````*0```$@````````````````````/````+0`````````(````70``
M`"8`````````!P`````````?````-0````````!+`````P```$$`````````
M-P````````````````````````!$`````````#8```!.````7P````````!@
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````$```````````````````````````````
M```````````>````'``````````D```````````````B````(P``````````
M````"@`````````9````&````"\````6````````````````````#@``````
M```N````+````#(`````````````````````````````````````````/0``
M`"`````````````````````3```````````````[`````@````8`````````
M```````````Z````30`````````4``````````````!0```````````````Y
M``````````````!,`````````$(````-`````````$\````2````5@```#$`
M``!;``````````````````````````````"?```````````````2````#```
M````````````$@```!0``````````````!(```"&`P``#B(```,````2``P`
M'```````````````(@```"L``````````````!(```!/`P`````````````2
M````,0``````````````$@```#@``````````````!(```"7`P``3B@``"L`
M```2``P`/P``````````````$@```%P#`````````````!(```!'````````
M```````2````L@,``'DR``!G````$@`,`(H``````````````!(```!/````
M```````````2````O@,``#RA````````$``7`%\``````````````!(```!N
M```````````````2````=```````````````$@```'L``````````````!(`
M``"%```````````````2````CP```+!%````````$``-`)4`````````````
M`!(```">```````````````2````(`(`````````````$@```*0`````````
M`````!(```"R```````````````1````RP(`````````````(@```+\`````
M`````````!(```#%`P``)B0``#D````2``P`T@,``%\D``!3````$@`,`-X#
M``!(*0``VP8``!(`#`#-```````````````6````X```````````````$@``
M`&X#`````````````!(```#K```````````````2````]````("A```$````
M$0`8`/P``````````````!(````%`0`````````````2````10,`````````
M````$@```!$!`````````````!(```#K`P``)C\``#8"```2``P`)`$`````
M````````$0```#8!`````````````!(```!&`0`````````````2````5`$`
M````````````$@```%D!`````````````!$```!H`0`````````````2````
M]@,``#BA```$````$0`7`'<!`````````````!(```"#`0`````````````2
M````DP$`````````````$@```*@!`````````````!(```"S`0``````````
M```2````@0,``(2A````````$``8`/\"`````````````!(```#&`0``````
M```````2````,00``%`6````````$@`,`-0!`````````````!(```#<`0``
M```````````2````Z`$`````````````$@`````$``"R)```.0$``!(`#`#N
M`0`````````````2````^0$`````````````$@````T$``!<00``_@$``!(`
M#``*`@`````````````2````%P0``#RA````````$``8`",$``!7(0``3@``
M`!(`#``K!```6D,``#\"```2``P`$0(`````````````$@```+,"````````
M`````"(````P!```4!8````````2``P`&`(`````````````$@```#@$```1
M(@``%0(``!(`#`!%!```>2@``,\````2``P`'P(`````````````$@```%<$
M``#K)0``50```!(`#``H`@`````````````2````#@,`````````````$@``
M`#D"`````````````"````!-`@`````````````2````9`(`````````````
M$@```&4$``!`)@``/@```!(`#`!S`@`````````````2````?`(`````````
M````$@```(("`````````````!(````X`P`````````````2````AP(`````
M````````$@```"L#``!`H0``!````!$`&`"/`@`````````````2````8P,`
M````````````$@```)8"`````````````!(```!M!```SSX``%<````2``P`
MG0(`````````````$0```"`#````H0``!````!$`%P!P!```0!(````````0
M``D`=@0``",P``!6`@``$@`,`!T!`````````````!(```"B`@``````````
M```2````=0,`````````````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M
M;6]V90!?7V-X85]F:6YA;&EZ90!R;61I<@!S=')S='(`<W1R8VAR`'-T<FYC
M;7``<W1R<F-H<@!B;V]T7T1Y;F%,;V%D97(`<&5R;%]C;VYS=')U8W0`86)O
M<G0`=6YL:6YK`%]?;'-T870U,`!P97)L7V9R964`7V9I;FD`7U]S=&%T-3``
M7V5X:70`<&5R;%]D97-T<G5C=`!03%]D;U]U;F1U;7``4&5R;%]S=E]S971P
M=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!C;&]S961I<@!E;G9I
M<F]N`')E861L:6YK`%]?;W!E;F1I<C,P`%!E<FQ?<V%F97-Y<VUA;&QO8P!?
M7W-T86-K7V-H:U]G=6%R9`!097)L7V=V7V9E=&-H<'8`7U]S<')I;G1F7V-H
M:P!R96%D`%!,7VUE;6]R>5]W<F%P`%!E<FQ?<WES7VEN:70S`%!E<FQ?9V5T
M7W-V`%]?7W1L<U]G971?861D<@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L
M7VYE=UA3`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R
M;F\`4&5R;%]M9U]S970`;6MD:7(`<&5R;%]P87)S90!097)L7VYE=UA37V9L
M86=S`&%C8V5S<P!G971P:60`;65M8VAR`'9F<')I;G1F`%!E<FQ?871F;W)K
M7VQO8VL`7TIV7U)E9VES=&5R0VQA<W-E<P!?7W-T86-K7V-H:U]F86EL7VQO
M8V%L`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?<G5N`&QS965K`&]P96X`<W!R:6YT
M9@!G971U:60`<W1R;&5N`%]?<T8`<W1R8VUP`&QI8FTN<V\N,`!?7V1E<F5G
M:7-T97)?9G)A;65?:6YF;P!?7W)E9VES=&5R7V9R86UE7VEN9F\`;&EB8W)Y
M<'0N<V\N,0!L:6)P=&AR96%D+G-O+C$`<'1H<F5A9%]A=&9O<FL`<W1R9'5P
M`&QI8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN9W,`7U]G971P=W5I
M9#4P`%]?<WES8V%L;`!?7W-T<&-P>5]C:&L`871E>&ET`%]L:6)C7VEN:70`
M<W1R=&]K`%]?<F5A9&1I<C,P`%]E;F0`<&%R7V-U<G)E;G1?97AE8P!G971?
M=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`<&%R
M7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!S:&%?=7!D871E
M`&UY7W!A<E]P;`!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T
M`'AS7VEN:70`;6%I;@!?7W-T87)T`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?96YV7V-L96%N`'!A<E]D:64`<VAA7VEN:70`6%-?26YT
M97)N86QS7U!!4E]"3T]4`"]U<W(O<&MG+VQI8B]P97)L-2\U+C,X+C`O:3,X
M-BUN971B<V0M=&AR96%D+6UU;'1I+T-/4D4Z+W5S<B]P:V<O;&EB`````/"?
M```(`````*$```@````$H0``"````#BA```(````S)\```8%``#0GP``!A``
M`-2?```&'```V)\```8=``#<GP``)2(``."?```&+```Y)\```8P``#HGP``
M!C<``.R?```&2```])\```9/``#XGP``!E$``/R?```&7P``#*````<!```0
MH```!P(``!2@```'`P``&*````<&```<H```!P<``""@```'"```)*````<)
M```HH```!PL``"R@```'#```,*````<-```TH```!P\``#B@```'$@``/*``
M``<3``!`H```!Q0``$2@```'%0``2*````<6``!,H```!Q@``%"@```'&0``
M5*````<:``!8H```!QL``%R@```''@``8*````<C``!DH```!R0``&B@```'
M)0``;*````<G``!PH```!R@``'2@```'*0``>*````<J``!\H```!RT``("@
M```'+@``A*````<O``"(H```!S$``(R@```',P``D*````<T``"4H```!S4`
M`)B@```'-@``G*````<Y``"@H```!SH``*2@```'/```J*````<]``"LH```
M!SX``+"@```'0```M*````=!``"XH```!T,``+R@```'1P``P*````=*``#$
MH```!TT``,B@```'4```S*````=2``#0H```!U,``-2@```'50``V*````=6
M``#<H```!U<``."@```'6```Y*````=9``#HH```!UL``.R@```'7```\*``
M``==``#TH```!V,``/B@```'9```_*````=E`````````````%6)Y>BH!P``
MR<,```````#_LP0```#_HP@`````````_Z,,````:`````#IX/____^C$```
M`&@(````Z=#_____HQ0```!H$````.G`_____Z,8````:!@```#IL/____^C
M'````&@@````Z:#_____HR````!H*````.F0_____Z,D````:#````#I@/__
M__^C*````&@X````Z7#_____HRP```!H0````.E@_____Z,P````:$@```#I
M4/____^C-````&A0````Z4#_____HS@```!H6````.DP_____Z,\````:&``
M``#I(/____^C0````&AH````Z1#_____HT0```!H<````.D`_____Z-(````
M:'@```#I\/[___^C3````&B`````Z>#^____HU````!HB````.G0_O___Z-4
M````:)````#IP/[___^C6````&B8````Z;#^____HUP```!HH````.F@_O__
M_Z-@````:*@```#ID/[___^C9````&BP````Z8#^____HV@```!HN````.EP
M_O___Z-L````:,````#I8/[___^C<````&C(````Z5#^____HW0```!HT```
M`.E`_O___Z-X````:-@```#I,/[___^C?````&C@````Z2#^____HX````!H
MZ````.D0_O___Z.$````:/````#I`/[___^CB````&CX````Z?#]____HXP`
M``!H``$``.G@_?___Z.0````:`@!``#IT/W___^CE````&@0`0``Z<#]____
MHY@```!H&`$``.FP_?___Z.<````:"`!``#IH/W___^CH````&@H`0``Z9#]
M____HZ0```!H,`$``.F`_?___Z.H````:#@!``#I</W___^CK````&A``0``
MZ6#]____H[````!H2`$``.E0_?___Z.T````:%`!``#I0/W___^CN````&A8
M`0``Z3#]____H[P```!H8`$``.D@_?___Z/`````:&@!``#I$/W___^CQ```
M`&AP`0``Z0#]____H\@```!H>`$``.GP_/___Z/,````:(`!``#IX/S___^C
MT````&B(`0``Z=#\____H]0```!HD`$``.G`_/___Z/8````:)@!``#IL/S_
M__^CW````&B@`0``Z:#\____H^````!HJ`$``.F0_/___Z/D````:+`!``#I
M@/S___^CZ````&BX`0``Z7#\____H^P```!HP`$``.E@_/___Z/P````:,@!
M``#I4/S___^C]````&C0`0``Z4#\____H_@```!HV`$``.DP_/___Z/\````
M:.`!``#I(/S___^CS/___V:0_Z/8____9I#_H^S___]FD/^C^/___V:04U+H
MJ@$``&:09I!FD&:0D%93Z#8O``"!PIF)``"-FMC^__^-@MC^__\YPW,;@\`#
MC9+<_O__*=#!Z`*-=(,$_Q.#PP0Y\W7W6U[#5U93Z/XN``"!PUV)``"+4`P#
M4`2+`(U4D`B+`H7`#X2S````OO__```QR>L:@_@'#X26````@_@#=0.+2@2#
MP@B+`H7`=!*#^`5UX0^W<@2#P@B+`H7`=>Z%R71Z9H/^_W1TP>8%C00Q.<%S
M:C'_@\[_ZQ&#^@9U!8G.*W$(@\$@.<AV$(L1@_H"=>B)SX/!(#G(=_"%_W0^
M@_[_=#F+3P@!\8L1A=)T+C'_,<#K$8/Z$G4#BWD$@\$(BQ&%TG0;@_H1=>J+
M000!\.OKBT($A<`/A&?___];7E_#C0PX.<AR$8UV`.OP@_HJ=1B#P`@YP7;D
M#[90!(/Z"'7KBQ`!\@$RZ^CH?/O__U575E.#[`3HZ2T```50B```B00DC;`X
M<O__C8`X<O__.<9S*8!^!"IU*XGR]]*-+`*#Y?@!]>L)@\8(@'\,*G44B?>+
M'O\3B0,Y[G7K@\0$6UY?7<.+'"3H'_O__U575E.#[!CHE"T``('#\X<``(ML
M)"R+="0PB?#H>?[__X7V#X07`0``C8-``0``B3"-@X`!``")P8E$)!2+1@B)
M`8L&BQ"%T@^$WP```(V+``$``(D1BP`/MA"$TG01@\`!@/HO=?&)`0^V$(32
M=>^%[70(B2PDZ&/Z___H7OW__XN#\/___X7`#X3K````C8/8_O__C9/8_O__
M.=!S'8/"`XV+W/[__RG*P>H"C6R0!(G'_Q>#QP0Y[W7WC8-@=O__B00DZ!7Z
M__^-@]C^__^-D]C^__\YT',=@\(#C8O<_O__*<K!Z@*-;)`$B<?_%X/'!#GO
M=?>-@["E__^)!"3HVOG__^@U^?__BT0D%(L`B40D"(L&B40D!(M&!(D$).@T
M*@``B00DZ#+Y__^-@P`!``"-DT0!``")$.DP____QT0D$!,```"-@[RE__^)
M1"0,QT0D"`(```#'!"0$````QT0D!`````#HD?K__\<$)`$```#H]?G__^@D
M_O__Z0O___^+'"3#4U>#[`CH\O___X'#;88``("[*0$```!U2,:#*0$```&#
MN\S___\`=`Z+@P0!``")!"3H</S__XV[Y/[__XL'A<!T!__0@\<(Z_.#N^S_
M__\`=`Z-@ZCH__^)!"3H5OS__X/$"%];PU-7@^P(Z(O___^!PP:&``"`NR@!
M````=5G&@R@!```!@[O8____`'08C;L(`0``B7PD!(V[J.C__XD\).@'_/__
M@[OX____`'04C;OH_O__BS^%_W0(B3PDZ/K[__^-N]C^__^+!X/X_W0'_]"#
M[P3K\H/$"%];PV:09I!FD&:055=64X/L&.@E*P``@<.$A0``A<`/A)@```"-
MBX`!``"+"8E,)!"%R0^$A`````^V"(3)=`6`^3UU1C'VBWPD$(LOA>UT,(E4
M)!2)1"0,B70D"(M$)`R)1"0$B2PDZ/[W__^%P'4'@'PU`#UT*(/'!(LOA>UU
MV(GH@\086UY?7<.)QH/&`0^V#H3)=`6`^3UU\2G&ZZ>)^BM4)!#!^@*+1"04
MB1"-;#4!B>B#Q!A;7E]=PS'MZ\!55U93@^P,Z&\J``"!P\Z$``")QXN#X/__
M_XD$)(L(B4PD"#')C70D!(VK@`$``(GRB?CH$O___X7`="R+10"+5"0$C020
MBU`$B1"%TG3@@\`$BU`$B1"%TG7TB?*)^.CF_O__A<!UU(L$)(M,)`@S"'4(
M@\0,6UY?7</HNOG__U575E.![*0```#H["D``('#2X0``(G"BZO@____BT4`
MB80DH````#'`A=)T!8`Z`'4;BX0DH````#-%``^%*@$``('$I````%M>7UW#
MB10DB50D&.CQ]___B40D$(7`=-&-@]&E__^)1"04C8/0I?__B40D'(M$)!")
M!"3H^?G__X7`#X2S````C5`-N0(```")UHM\)!3SI@^7P!P`A,!TT[D#````
MB=:+?"0<\Z8/E\`<`(3`=+V)5"0@BWPD&(D\).B"^?__B<:+5"0@B10DZ'3Y
M__^-1`8"B00DZ'CY__^)QHM4)"")5"0,B7PD"(V#TZ7__XE$)`2)-"3H&/G_
M_XU$)"2)1"0$B30DZ*CV__^#^/]T$(M$)"PE`/```#T`0```=#J)-"3H6_;_
M_XDT).@C]O__Z3G___^+5"08B50D%(M$)!")!"3HVO;__XM4)!2)%"3HCO7_
M_^G1_O__B?#HF/[__V:0Z\/H2?C__U575E.#["CH?B@``('#W8(``(G%B=:+
M@^#___^)1"04BSB)?"0D,?^`.CUU`X/&`8DT).BA^/__B40D#(U4)"")Z.@2
M_?__B<>%P`^$XP```(D$).B`^/__.T0D#`^#O@```(M$)""-#(4`````C8.`
M`0``B40D$`^V10"$P`^$:@$``#P]#X1B`0``B>CK!8#Z/70*@\`!#[80A-)U
M\2GHBU0D$(LZ`<^+3"0,C40(`HD$).@P^/__B0>%P`^$/@$``(M4)!"+`HM4
M)""+%)"-30$/MD4`B`*$P'42ZQ2#P@&#P0$/MD'_B`*$P'0$/#UU[,8"/3'`
M#[8,!HA,`@&#P`&$R77Q,<"+?"04BW0D)#,W#X7R````@\0H6UY?7<.#Q@&#
MQP$/MD;_B$?_A,!U[^O3C8.``0``B40D$(L0BSJ%_P^$JP```#'`ZP*)^(UX
M`8L,NH7)=?2-!(4,````BXM(`0``A<EU8(E4)!C'@T@!```!````B00DZ&CW
M__^%P'1\C0R]`````(E,)`B)3"0<BU0D&(E4)`2)1"08B00DZ,'S__^+3"00
MBT0D&(D!BTPD'(M$)!C'1+@$`````(E\)"#IK?[__XE$)`2)%"3H@O/__XE$
M)!B+3"00B0&%P'0<C0R]`````.O(,<#IK/[__[@(````,?_I8/___[C_____
MZ?[^___H.?;__U=64X'LB````.AL)@``@</+@```B<>+L^#___^+!HF$)(0`
M```QP(U$)`B)1"0$B3PDZ.+S__^%P'5)BU0D$('B`/```('Z`$```'0=@?H`
MH```=!6+C"2$````,PYU*('$B````%M>7\/'1"0$`@```(D\).AO]?__A<`/
ME,`/ML#KT3'`Z\WHK/7__U6)Y5=64X/D\('L,`0``.C9)0``@<,X@```B40D
M)(E4)""+@^#___^)1"0HBPB)C"0L!```,<G'1"0(_P,``(UT)"R)="0$C8/9
MI?__B00DZ-?S__^)1"0<A<`/CHD```"->/]EH0`````K@]S___^+$(!\/"P`
M=%.+?"0<B50D'(E\)`C'1"0$+P```(DT).CG]/__A<"+5"0<=#.)?"0,B70D
M"(M$)"2)1"0$B10DZ`?U__^+1"0HBXPD+`0``#,(=3:-9?1;7E]=PX7_=:V+
M1"0@B40D"(M$)"2)1"0$B10DZ`3S___KRV6A`````"N#W/___XL0Z];HK?3_
M_U=64X'L$`0``.C@)```@<,_?P``B[O@____BQ>)E"0,!```,=+'1"0(``0`
M`(E$)`2-="0,B30DZ+#Q__^#Z`$Y\'<,ZP_&``"#Z`$Y\'0%@#@O=/''1"0$
M+P```(DT).C8\?__A<!T)CGP=QV)-"3H*/3__XN,)`P$```S#W4?@<00!```
M6UY?P\8``.O>C8/1I?__B00DZ`#T___KUN@)]/__58GE4X/D\(/L$.@[)```
M@<.:?@``C8,@YO__B40D#(N#T/___XE$)`B-@^NE__^)1"0$9:$`````*X/<
M____BP")!"3H\/+__XM=_,G#58GE5E.#Y/"#["#H[",``('#2WX``&6A````
M`"N#W/___XG&BP")!"3HA/___\=$)!0`````C8//I?__B40D$(E$)`R-@R.0
M__^)1"0(C8,'IO__B40D!(L&B00DZ/GR__^-9?A;7EW#,<##55=64X'LL`0`
M`.B!(P``@</@?0``BZPDQ`0``(NT),@$``"+@^#___^)1"0HBQ")E"2L!```
M,=*-5"0LC8,<IO__Z!CX__^)Q\=$)`0O````B2PDZ%;P__^%P'0MB>J-@R6F
M___HG/K__XGHBTPD*(N4)*P$```S$0^%D0$``('$L`0``%M>7UW#B30DZ*WR
M__^-BS*F__^)3"0@B4PD!(D$).@'\?__B<:%P'2OC8/1I?__B40D)(EL)!R)
M_8`^``^$\P```(7M=!2)="0$B2PDZ"CS__^%P`^$M````(DT).CX\O__B<>-
M1`;_.<9S)(`X+W0+ZQV`."^-="8`=0K&``"#Z`$YQG7MB30DZ,SR__^)QXM$
M)!R)!"3HOO+__XU$!P$]_P,```^'@0```(M$)!R)1"08C8,7I___B40D%(ET
M)!"-@SJG__^)1"0,QT0D"``$``#'1"0$`````(VT)*P```")-"3HL/#__XU$
M)#")1"0$B30DZ-#O__^%P'40BT0D."4`\```/0"```!T3XM$)"")1"0$QP0D
M`````.@(\/__B<:%P`^%#?___XML)!SIH_[__X7M=!:Y`@```(GNBWPD)/.F
M#Y?`'`"$P'2_OP$```"+="0DZ3/____'1"0$`0```(DT).@-\?__A<!UG8GR
MC8,EIO__Z`/Y__^)-"3H-/'__^E<_O__Z#KQ__]64X/L".AQ(0``@</0>P``
MBW0D%,=$)`0O````B30DZ*;N__^%P'0#C7`!B30DZ/?P__^#Q`A;7L-64X/L
M!.@X(0``@<.7>P``BW0D$(7V=".`/@!T'HDT).AL\?__@\`!/0`$``!W((GP
M@\0$6U[I&?S__XV#T:7__XD$).BH\/__@\0$6U[#,<#K]E=64X/L".CD(```
M@<-#>P``B[O@____BP>)1"0$,<"-@S2F___H2O;__XV#/:;__^@_]O__C8-%
MIO__Z#3V__^-@TZF___H*?;__XV#5:;__^@>]O__C8-EIO__Z!/V__^-@QRF
M___H"/;__XV#<:;__^C]]?__C8-[IO__Z/+U__^-@X6F___HY_7__XV#):;_
M_^C<]?__B>:)\HV#CZ;__^@7]?__A<!T#8G"C8-[IO__Z*WW__^)\HV#H*;_
M_^CY]/__A<!T#8G"C8.RIO__Z(_W__^)\HV#O:;__^C;]/__A<!T+8G"C8,<
MIO__Z''W__^-DZ:G__^-@U6F___H8/?__XM$)`0S!W4G@\0(6UY?PXGRC8/-
MIO__Z)WT__^%P'3/B<*-@W&F___H,_?__^O`Z'7O__]64X/L".BL'P``@<,+
M>@``B[/@____BP:)1"0$,<")XHV#<:;__^A:]/__A<!T$0^V`(3`=`H\,`^5
MP`^VP.L",<"+3"0$,PYU!H/$"%M>P^@@[___4X/L#.A8'P``@<.W>0``C40D
M&(E$)`B+1"04B40D!(N#_/___P6P````B00DZ,[N___'!"3_````Z.+K__]5
MB>575E.![#0``0#H$A\``('#<7D``(E$)"2+N^#___^)?"00BS>)M"0P``$`
M,?;'1"0,`@```,=$)`0`````QT0D"`````")!"3HPN[__X/`_X/2_XG&B=<E
M__\``(E$)!R)T"4```"`B40D((7`>2.#1"0<_XM$)!P-``#__[G_____B<J#
MP`&#T@")1"0<B50D("MT)!P;?"0@A?\/B/,```"-3"0HC8/>IO__B40D&(V#
MZZ;__XE$)!2)3"0<QT0D#`````")="0$B7PD"(M$)"2)!"3H->[__R'0@_C_
MBTPD'`^$R@```,=$)`@(``$`B4PD!(E,)!R+1"0DB00DZ+KL__^#^/^+3"0<
M#X2/````@_@'=F*-1`'X.<AR6HT5+`$``(ET)!R)?"0@ZP>#Z`$YR'([BSP:
M.3AU\HNS,`$``#EP!'7GBW0D'(M\)"`IR)D!\!'ZBWPD$(NT)#```0`S-W5B
M@<0T``$`6UY?7<.+="0<BWPD(('&``#__X/7_XGZ]]*)\#4``/__"<(/A27_
M__^X_____[K_____Z[:+1"04B00DZ!+^__^+3"0<Z\:+1"08B00DZ`#^__^+
M3"0<Z2'____H$NW__U.#[`3H2AT``('#J7<``.AN[?__B00DZ$;M__^%P'0'
MBP"#Q`1;PS'`Z_=55U93@^P@Z!P=``"!PWMW``"+?"0TB[/@____BP:)1"0<
M,<"-5"08C8/WIO__Z,3Q__^%P'1VB<6`.`!T;XE\)`2)!"3H[>G__X7`=6R)
M/"3H(>W__XE$)!2)+"3H%>W__XM4)!2-1`("B00DZ!7M__^)PHEL)!"-@S*F
M__^)1"0,B7PD"(V#.J?__XE$)`2)%"2)5"04Z*OL__^+5"04C8/WIO__Z//S
M___K#8GZC8/WIO__Z.3S__^+1"0<,P9U"(/$(%M>7UW#Z!CL__]55U93@>P<
M`0``Z$H<``"!PZEV``"+A"0P`0``B40D+(N#X/___XE$)#"+"(F,)!@!```Q
MR8V#$Z?__XE$)#R-@]&E__^)1"1`QT0D1`````"-@[*F__^)1"0@B40D5(V#
MJZ;__XE$)%B-@QFG__^)1"1<C8/(IO__B40D8(V#(:?__XE$)&3'1"1H````
M`(V[!Z?__XE\)$B-@R6G__^)1"1,QT0D4`````"-5"0XB50D)(V#'*;__^AJ
M\/__A<!T"8`X``^%!0(``.@V_O__B<6%P`^$,`(``(DL).C&Z___C40``8D$
M).C*Z___B40D'(!]``!T*HMT)!R-NRZG__\/MD4`B40D"(E\)`2)-"3H8NO_
M_X/%`8/&`H!]``!UX(U\)%2+1"0@BVPD).L-@\<$BP>%P`^$7`$``(GJZ.3O
M__^)QH7`=.:`.`!TX>B+]/__A<!FD'36B30DZ*;J__^)QH7`#X0M`0``B?"+
M"(/`!(V1__[^_O?1(<J!XH"`@(!TZ??"@(````^$S`$``(G1`-&#V`,I\(M\
M)!R)^8LY@\$$C9?__O[^]]<A^H'B@("`@'3IB<_WPH"```!U!L'J$(/'`HG1
M`-&#WP.+;"0<*>^-O#@$!```B3PDZ-7J__^)P8E$)!R);"04C8,SI___B40D
M$(V#%Z?__XE$)"")1"0,B70D"(V#.*?__XE$)`2)SHD,).A;ZO__QT0D!,`!
M``")-"3H:^G__X/X_P^$,@$``(U$)&R)1"0$BT0D'(D$).BNY___B40D-(7`
M=12+1"1T)0#P```]`$````^$4P$``(M$)!R)1"0,BT0D+(L`B40D"(V#[*?_
M_XE$)`2+@_S___\%L````(D$).BCY___,>WK43'_BW2\/(7V=":`/@!T(8GP
MZ##S__^#QP&%P'3EB30DZ$KI__^%P'39B<;IH_[__S'VZ9S^__^)!"2)1"0<
MZ%7\__^+1"0<B00DZ"#I__^)Q8GHBTPD,(N4)!@!```S$0^%UP,``('$'`$`
M`%M>7UW#B?@Q_X7`=!V+5"0DZ`WN__^#QP&%P'0%@#@`=2.+1+Q(A<!UX\<$
M)`T```#H?>G__XE$)!R-JPRG___IKOW__XD$).BVZ/__A<!TT8G%Z7W]___!
MZA"#P`+I*?[__^@+Z/__@S@1#X3`_O__9I#H^^?__XL`B40D$(M$)!R)1"0,
MBT0D+(L`B40D"(V#L*?__XE$)`2+@_S___\%L````(D$).B&YO__,>WI,?__
M_XNT)(0```#HP^C__SG&#X69_O__BT0D="7_`0``/<`!```/A87^__^)/"3H
MS^C__XG%BU0D)(V#`J?__^@N[?__A<`/A%P!``")1"0$BT0D+(L`B00DZ+7T
M__^)1"0DA<`/A#X!``"+?"0DB3PDZ'SH__^#^`-V-XE\)"2-=`?\N04```"-
MNT&G___SI@^7PH#:`(32=1B#^`0/A"X"``"+?"0D@'P'^R\/A!\"``#H-OC_
M_X7`=1['1"0$`````(M$)"2)!"3HT^?__XG&A<`/A=X```"-DZ:G__^-@W&F
M___H+^___^@SY___C;//I?__B70D%(E$)!"+1"0@B40D#(M$)!R)1"0(C8-E
MI___B40D!(DL).BCY___C;MSI___B70D)(MT)#3K/NB.YO__@S@1=4F#Q@'H
MX>;__XM,)"2)3"08B70D%(E$)!"+1"0@B40D#(M$)!R)1"0(B7PD!(DL).A5
MY___QT0D!,`!``")+"3H9>;__X/X_W2MBT0D'(D$).ATY/__B>J-@QRF___H
M?N[__XDL).C8^?__Z8S]__^+1"0LBP")1"0DZ;/^___HQ/?__XE$)"2)5"0H
MA=(/B`W____'1"0,`````(/`]H/2_XE$)`2)5"0(B30DZ*CF___'1"0(!@``
M`(V$).D```")1"0$B30DZ#WE__^#^`9T#HV#2Z?__XD$).@J]___BX,8YO__
M.80DZ0````^%KO[__P^W@QSF__]F.80D[0````^%F?[__\=$)`P`````BT0D
M)(M4)"B#P,Z#TO^)1"0$B50D"(DT).@LYO__QT0D""@```"-O"3O````B7PD
M!(DT).C!Y/__@_@H=`Z-@TNG__^)!"3HKO;__\:$)!<!````C8//I?__B40D
M%(E\)!"+1"0@B40D#(M$)!R)1"0(C8-6I___B40D!(DL).CVY?__Z;'^__^+
M1"0LBU`$A=(/A-+]__^)%"2)5"0LZ`;F__^#^`,/AKW]__^+5"0LC70"_+D%
M````C;M&I___\Z8/E\`<`(3`#X6;_?__B50D).F2_?__Z#WE__]5B>575E.#
MY/"#["#H;14``('#S&\``(N[X/___XL'B40D'#'`9:$`````*X/<____BP`/
MME!DB%!EC40D&(E$)!2)PHV#5:;__^C^Z?__A<!T"8`X,0^$E`$``)#H+?3_
M_\=$)`P#````QT0D"`$```"-@X2G__^)1"0$9:$`````*X/<____B<:+`(D$
M).AIX___A<!T-(V3AJ?__XE4)`B+4`R)1"00BQ*)5"0$BQ:)%"3HQ.+__XM$
M)!"+0`R+`/9`"D`/A4H!``#'1"0,`P```,=$)`@!````C8.+I___B40D!&6A
M`````"N#W/___XG&BP")!"3H_^+__X7`B40D$'0RBU0D%(V#):;__^@XZ?__
MA<"+3"00#X3>````B40D"(M!#(L`B40D!(L&B00DZ$7B___'1"0(`0```(V#
MC:?__XE$)`1EH0`````K@]S___^)QHL`B00DZ-OB__^-DZ*G__^)5"0(B40D
M!(L&B00DZ`/B__^+!L9`90"+5"04C8,<IO__Z+[H__^)@TP!``"%P'0QQT0D
M!,`!``")!"3H%./__X/X$70(C5`!@_H!=W.+1"0<,P</A8\```"-9?1;7E]=
MPXN#4`$``(D$).A-]___B8-,`0``A<!UMXV#0*C__XD$).AMXO__@'@!``^$
M:/[__^E=_O__BT$,BY-0`0``BQ*+`.B`[?__Z2+___^)1"0$BP:)!"3HB>+_
M_^FC_O__B40D#(N#3`$``(E$)`B+@U`!``"+`(E$)`2-@V2H__^)!"3H#.+_
M_^CGXO__55=64X/L!.@<$P``@<-[;0``BVPD&.A7\___A<!T"H7M=`:`?0``
M=0B#Q`1;7E]=PXDL).BM\?__B00DZ&SQ__^Y!````(V[,Z?__XG&\Z8/E\`<
M`(3`==")Z(/$!%M>7UWIQNC__U575E.![&0!``#HMA(``('&$6T``(ET)!R)
M!"2+MN#___^)="08BSZ)O"1@`0``,?^-6!PQP(U4)""+#(,/R8D,@H/``8/X
M$'7PC8PD(`$``(M"-#-"(#-""#,"T<")0D"#P@0YRG7IBSPDBS>+7P2+;PB+
M3PR+1Q")PHM$)"")5"04C90"F7F"6HGPP<`%`=")ZC'*(=J)3"0$,<H!PHE<
M)`R)V<')`HGH,<B)]R'P,>B+7"0DBW0D!(VT'IEY@EH!QHG0P<`%`<:)?"0(
MB?C!R`*)QXG(,?@AT#'(BUPD*(EL)!"-G!V9>8):`<.)\,'`!0'#P<H"B?@Q
MT"'P,?B+;"0LC8PIF7F"6@'(B=W!Q04!Z,'.`HG5,?6)Z2'9,=&+;"0PC;PO
MF7F"6@'YB<7!Q04!Z<'+`HGU,=V)[R'',?>+;"0TC90JF7F"6@'ZB<W!Q04!
MZL'(`HG'B=@Q^"'(,=B+;"0XC;0NF7F"6@'PB=;!Q@4!\(G.P<X"B?TQ]8GI
M(=$Q^8ML)#R-G"N9>8):`=F)P\'#!0'9B=/!RP*)\C':(<(Q\HML)$"-O"^9
M>8):`?J)S<'%!0'JP<@"B<>)V#'X(<@QV(ML)$2-M"Z9>8):`?")UL'&!0'P
MB<[!S@*)_3'UB>DAT3'YBVPD2(V<*YEY@EH!V8G#P<,%`=F)T\'+`HGR,=HA
MPC'RBVPD3(V\+YEY@EH!^HG-P<4%`>K!R`*)QXG8,?@AR#'8BVPD4(VT+IEY
M@EH!\(G6P<8%`?")SL'.`HG],?6)Z2'1,?F+;"14C9PKF7F"6@'9B</!PP4!
MV8G3P<L"B?(QVB'",?*+;"18C;POF7F"6@'ZB<W!Q04!ZL'(`HG%B=@QZ"'(
M,=B+?"1<C;0^F7F"6@'PB=;!Q@4!\,')`HGN,<XAUC'NBWPD8(V\.YEY@EH!
M_HG#P<,%B=\!]\'*`HG+,=,APS'+BW0D9(VT-9EY@EH!\XG^P<8%`=[!R`*)
MTS'#(?LQTXML)&B-C"F9>8):`<N)]<'%!0'KP<\"B<4Q_8GI(?$QP8ML)&R-
ME"J9>8):`=&)VL'"!0'1P<X"BU0D<(V$$*'KV6Z)^C'R,=H!PHG(P<`%`<+!
MRP*+1"1TC;P'H>O9;HGP,=@QR`'XB=7!Q04!Z(G-P<T"B>^+3"1XC;0.H>O9
M;HG=,?V)Z3'1`?&)QL'&!0'QB=;!S@*+5"1\C9P3H>O9;HGZ,?(QP@':B<O!
MPP4!VL'(`HG#BX0D@````(V\!Z'KV6Z)\#'8,<@!^(G5P<4%`>B)S<'-`HGO
MBXPDA````(VT#J'KV6Z)W3']B>DQT0'QB<;!Q@4!\8G6P<X"BY0DB````(V<
M$Z'KV6Z)^C'R,<(!VHG+P<,%`=K!R`*)PXN$)(P```"-O`>AZ]ENB?`QV#'(
M`?B)U<'%!0'HB<W!S0*)[XN,))````"-M`ZAZ]ENB=TQ_8GI,=$!\8G&P<8%
M`?&)UL'.`HN4))0```"-G!.AZ]ENB?HQ\C'"`=J)R\'#!0':P<@"B<.+A"28
M````C;P'H>O9;HGP,=@QR`'XB=7!Q04!Z(G-P<T"B>^+C"2<````C;0.H>O9
M;HG=,?V)Z3'1`?&)QL'&!0'QB=;!S@*+E"2@````C9P3H>O9;HGZ,?(QP@':
MB<O!PP4!VL'(`HG#BX0DI````(V\!Z'KV6Z)\#'8,<@!^(G5P<4%`>B)S<'-
M`HGOBXPDJ````(VT#J'KV6Z)W3']B>DQT0'QB<;!Q@4!\8G6P<X"BY0DK```
M`(V<$Z'KV6Z)^C'R,<(!VHG+P<,%`=K!R`*)PXN$)+````"-O`>AZ]ENB?`Q
MV#'(`?B)U<'%!0'HB<W!S0*)[XN,)+0```"-M`ZAZ]ENB=TQ_8GI,=$!\8G&
MP<8%`?&)UL'.`HN4)+@```"-G!.AZ]ENB?HQ\C'"`=J)R\'#!0':P<@"B<6+
MA"2\````C9P'H>O9;HGP,>@QR`'8B=/!PP4!V,')`HGK"<LATXG?B>LARPG[
MB[PDP````(VT/MR\&X\!\XG&P<8%`?/!R@*)S@G6(<:)]XG.(=8)_HN\),0`
M``"-O#W<O!N/`?Z)W<'%!8GO`??!R`*)U@G&(=Z)]8G6(<8)[HNL),@```"-
MC"G<O!N/`<Z)_<'%!0'NP<L"B=V)PPGK(?N)P2'I"=F+G"3,````C9P:W+P;
MCP'9B?/!PP4!R\'/`HGJ"?HA\HG1B>HA^@G*BXPDT````(V,"-R\&X\!RHG8
MP<`%B<$!T<'.`HGX"?`AV(G"B?@A\`G0BY0DU````(V4%=R\&X\!T(G*P<(%
M`<+!RP*)\`G8(<B)Q8GP(=@)Z(NL)-@```"-O"_<O!N/`?B)U<'%!0'HB<W!
MS0*)[XG="?TAU8G9(?D)Z8NL)-P```"-M"[<O!N/`?&)QL'&!0'QB=;!S@*)
M^@GR(<*)U8GZ(?()ZHNL).````"-G"O<O!N/`=J)R\'#!0':P<@"B<.)\`G8
M(<B)Q8GP(=@)Z(NL).0```"-O"_<O!N/`?B)U<'%!0'HB<W!S0*)[XG="?TA
MU8G9(?D)Z8NL).@```"-M"[<O!N/`?&)QL'&!0'QB=;!S@*)^@GR(<*)U8GZ
M(?()ZHNL).P```"-G"O<O!N/`=J)R\'#!0':P<@"B<.)\`G8(<B)Q8GP(=@)
MZ(NL)/````"-O"_<O!N/`?B)U<'%!0'HB<W!S0*)[XG="?TAU8G9(?D)Z8NL
M)/0```"-M"[<O!N/`?&)QL'&!0'QB=;!S@*)^@GR(<*)U8GZ(?()ZHNL)/@`
M``"-G"O<O!N/`=J)R\'#!0':P<@"B<6)\`GH(<B)PXGP(>@)V(N<)/P```"-
MG!_<O!N/`=B)T\'#!0'8P<D"B>L)RR'3B=^)ZR'+"?N+O"0``0``C;0^W+P;
MCP'SB<;!Q@4!\\'*`HG."=8AQHGWB<XAU@G^B[PD!`$``(V\/=R\&X\!_HG=
MP<4%`>[!R`*)U0G%(=V)UR''">^+K"0(`0``C8PIW+P;CP'YB?7!Q04!Z<'+
M`HG%"=TA]8G'(=\)[XNL)`P!``"-E"K<O!N/`=>)RL'"!0'7P<X"BY0D$`$`
M`(V4$-;!8LJ)V#'P,<@!T(GZP<(%`=#!R0*+E"04`0``C9P3UL%BRHGR,<HQ
M^@':B</!PP4!VL'/`HN<)!@!``"-M![6P6+*B<LQ^S'#`?.)UL'&!0'SB<;!
MS@*+A"0<`0``C8P!UL%BRHGX,?`QT`'(B=W!Q04!Z,'*`HG1BY0D(`$``(V4
M%];!8LJ)]3'-B>\QWP'7B<+!P@4!U\'+`HN4)"0!``"-M!;6P6+*B<HQVC'"
M`?*)_L'&!0'RB<;!S@*+A"0H`0``C80!UL%BRHG=,?6)Z3'Y`<&)T,'`!0'!
MP<\"BX0D+`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)T\'+`HN4)#`!``"-
ME!;6P6+*B?XQWC'.`=:)PL'"!0'6P<D"BY0D-`$``(V\%];!8LJ)VC'*,<(!
M^HGUP<4%`>K!R`*)QXN$)#@!``"-A`/6P6+*B<LQ^S'S`<.)T,'`!0'#P<X"
MBX0D/`$``(V,`=;!8LJ)^#'P,=`!R(G=P<4%`>C!R@*)T8N4)$`!``"-E!?6
MP6+*B?4QS8GO,=\!UXG"P<(%`=?!RP*+E"1$`0``C;06UL%BRHG*,=HQP@'R
MB?[!Q@4!\HG&P<X"BX0D2`$``(V$`=;!8LJ)W3'UB>DQ^0'!B=#!P`4!P<'/
M`HN$)$P!``"-G`/6P6+*B?`Q^#'0`=B)R\'#!0'8B=/!RP*+E"10`0``C906
MUL%BRHG^,=XQS@'6B<+!P@4!UL')`HN4)%0!``"-O!?6P6+*B=HQRC'"`?J)
M]<'%!0'JP<@"B[PD6`$``(V\.];!8LJ)RS'#,?,!^XG5P<4%`>O!S@*+O"1<
M`0``BVPD"(V\/=;!8LH!SXG%,?6)Z3'1`?F)W\''!0'YBSPDB0\#7"0,B5\$
MP<H"`U0D$(E7"`-T)`2)=PP#1"04B4<0BT0D&(N\)&`!```S.'4+@<1D`0``
M6UY?7<.+7"0<Z)'6__]3@^P$Z,D&``"!PRAA``#'!"1@````Z!;7___'``$C
M16?'0`2)J\WOQT`(_MRZF,=`#'94,A#'0!#PX=+#QT`4`````,=`&`````#'
M0%P`````@\0$6\-55U93@^P(BUPD((M4)"2-!-4`````BTPD'`-!%`^2P0^V
MR8G.BTPD'(M)&(7V=`.#P0&+?"0<B4<4B=#!Z!T!R(E'&(M/7(UO'(7)=&&^
M0````"G.B=`Y\@^/-0$``(D$)(U\#0")WH/X!`^#5@$``/8$)`(/A0L!``#V
M!"0!#X7[````BW0D'(M.7`'!B4Y<@_E`=`B#Q`A;7E]=PRG"B10D`<.)\.@.
M\___BQ0D@_H_#XZ4````C4+`B00DB<?![P:-=P'!Y@8!WHE\)`2+?"0<BP.)
M10"+0P2)102+0PB)10B+0PR)10R+0Q")11"+0Q2)112+0QB)11B+0QR)11R+
M0R")12"+0R2)122+0RB)12B+0RR)12R+0S")13"+0S2)132+0SB)13B+0SR)
M13R#PT")^.A^\O__.?-UDXM\)`3!YP:+%"0I^HG0B>^)WH/Z!'-3J`)U':@!
M=0^+1"0<B5!<@\0(6UY?7<.DBT0D'(E07.ON9J6H`73AZ^ZDZ?_^__]FI?8$
M)`$/A//^___K[(GPB00DC7P-`(G>@_@$#X+)_O__ZQWWQ0$```!U7O?'`@``
M`'5KB<'!Z0+SI:@"=);KL??'`0```'4N]\<"````=12+#"3!Z0+SI?8$)`(/
MA)+^___KFP^W#F:)#X/'`H/&`H,L)`+KV@^V"X@/@\<!C7,!C4C_B0PDZ[\/
MM@.+3"0<B$$<@\<!@\8!C4+_ZXT/MPYFB0^#QP*#Q@*#Z`+KA%575E.#[!#H
M,00```687@``B40D!(MT)"2+7"0HBU,4BT,8B40D"(G1P>D#@^$_C6L<C4$!
MQD0-`("-?`4`@_@X#XXN`0``N4`````IP70-,<#&!`<`@\`!.<AR]8E4)`R)
MV.@<\?__B>^].````#'`]\<!````BU0D#`^%<@$``/?'`@````^%7`$``(GI
MP>D"\ZOWQ0(```!T`F:K@^4!#X7L````BWPD"(GXP>@8B$-4B?C!Z!"(0U6)
M^(AC5HA#5XG0P>@8B$-8B=#!Z!"(0UF(<UJ(4UN)V.BD\/__BP/!Z!B(!HL#
MP>@0B$8!BP.(9@*+`XA&`P^V0P>(1@0/MT,&B$8%BT,$B&8&BT,$B$8'#[9#
M"XA&"`^W0PJ(1@F+0PB(9@J+0PB(1@L/MD,/B$8,#[=##HA&#8M##(AF#HM#
M#(A&#P^V0Q.(1A`/MT,2B$81BT,0B&82BT,0B$83B1PDBUPD!.@WT/__@\00
M6UY?7<.Y.````"G!,>V#^01S%O;!`G5!@^$!#X06____B>BJZ0[____WQP$`
M``!U-_?'`@```'4W@_D$<M6)R(/@_(E$)`PQP(DL!X/`!#M$)`QR]`''Z[J)
MZ&:K@^$!#X31_O__Z[F)Z*J#Z0'KP8GH9JN#Z0+KP&:K@^T"Z9K^__^JO3<`
M``#I@_[__U6)Y5=64X/D\(/L0.@V`@``@<.57```BT4,B40D-(M%$(E$)#"+
M@^#___^)1"0LBS")="0\,?:-1"0PB40D"(U$)#2)1"0$C44(B00DZ*30__^+
M@^C___^)1"0(B40D!(N#]/___XD$).C8T/__BX/4____@#@`#X06`0``9:$`
M````*X/<____BP"`B%H"```#BT4(C7@#@\`$/?___S\/AU,!``#!X`*)!"3H
M!=#__XF#4`$``(MT)#2+%HD0C9.HI___B5`$C9,X`0``BQ*)4`B-DZNG__^)
M4`R+30B#^0$/C@<!``"Z`0```(E\)"B+/):)?)`,@\(!.=%U\HM\)"B-%(T,
M````QP00`````,=$)!``````B40D#(E\)`B-@Z6!__^)1"0$BX-4`0``B00D
MZ%W0__^%P`^$FP```(N#5`$``(D$).CGSO__B<:-?"0XB?J-@V6F___HM-7_
M_X7`=&*+@U0!``")!"3H@L[__^C=S___B?"+="0LBTPD/#,.#X6C````C67T
M6UY?7</HOL[__XF#5`$``(7`#X2-````B00DZ`C.__]EH0`````K@]S___^+
M`,:`]@0```#IM?[__XN#3`$``(7`=#^)!"3H1>W__^N*BX-4`0``B00DZ#S0
M___I4O___[H0````Z1'___^+@^3___^)1"0$C8/6I?__B00DZ!7/__^)^HV#
M'*;__^CXU/__B8-,`0``A<`/A#K____KI.C3S___QP0D`0```.C'S/__BP0D
MPXL4),.+'"3#BS0DPP````````!5B>7HT=/__\G#``!P<U]S=')I;F=S(&UI
M<W-I;F<*`"XN`"5S+R5S`"]P<F]C+V-U<G!R;V,O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5`!005)?5$5-
M4`!005)?4%)/1TY!344`.@!015),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%
M4DQ)3P!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.`%!!
M4E]$14)51P!005)?0T%#2$4`4$%27T=,3T)!3%]$14)51P!005)?1TQ/0D%,
M7U1-4$1)4@!005)?5$U01$E2`%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.`&QS965K(&9A:6QE9`!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`55-%4@!365-414T`+W1M<"\`5$5-4$1)4@!435``55-%4DY!344`)3`R
M>`!P87(M`"5S)7,E<R5S`'!A<FP`+G!A<@!S:&]R="!R96%D`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`
M,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`V,0`M90`M+0```"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@
M*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`
M`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C<F5A
M=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@
M*&5R<FYO/25I*0H`````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D
M,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S
M:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@)$9)3$5?
M;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B!["B1005)?
M34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE(#T@-#L@
M("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B102UI)4%]-
M04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G:6,*>PIM
M>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@
M)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I>F4M,2D@
M+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@
M:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P
M*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK
M7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD
M97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P;W,@*R`D
M:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*?0IM>2`H
M)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE0V%C:&4I
M.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL93HZ
M5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A
M<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP
M(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD
M:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP.PII
M9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@)'1M
M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G+`I$
M25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-51D9)
M6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA;64@/2`D
M=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC;&]S92`D
M=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B)&9I;&5N
M86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO=71S*'%Q
M6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU
M<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS.CI005(Z
M.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/5#L*979A
M;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH
M/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@
M("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD[
M"E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@(B1P<F]G
M;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P;W,L("1S
M=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?
M5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@
M)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P
M<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER
M97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN
M9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S
M*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@
M4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T:"@B7#!#
M04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD[
M"FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,14%.(BD@
M>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-04=)0SL*
M?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*<F5A9"!?
M1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP
M86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T(&]F($9)
M3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L
M("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R96%D('1H
M92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K:6YG($9)
M3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^
M('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E
M;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI
M.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH
M/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H
M(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD36]D=6QE
M0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C
M+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA
M;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS
M=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@
M)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[
M)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER
M95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN
M9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H
M)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP
M9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H
M+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS
M965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*
M)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A
M=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE
M(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL
M960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E
M<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI
M;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;
M,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^
M("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR
M97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S
M<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE
M=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("10
M2UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%
M('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*
M?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@
M(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M
M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H
M"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L
M;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'
M5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD
M14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@
M;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H
M0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC
M+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*
M96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*
M96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q
M("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I
M('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U
M:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B
M/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D
M(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]
M"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2![
M"F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E
M(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%2
M1U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70[
M"GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I
M('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C
M:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F
M:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q
M6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T
M85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O
M;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS
M.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ
M("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D
M<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I
M;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID
M:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E
M<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I
M(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?
M0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U12
M54Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D
M;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY
M("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI
M('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX[
M"GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*
M?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*
M?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG
M(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO
M?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T
M96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H
M)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME
M>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF
M("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M
M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D
M97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D
M,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N
M86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H
M<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL
M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT
M(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[
M4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I
M.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N
M=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C
M:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L
M($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I
M+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@
M)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z
M:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T
M(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP
M<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE
M7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@
M)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R
M.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N
M9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP
M0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-
M04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A
M:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*
M?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G
M;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N
M($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@
M9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN
M97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I
M(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T
M<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?
M5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A
M8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE
M;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M
M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO
M/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=
M*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE
M(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A
M8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I;F<@(B1M
M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T
M7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B)&UE;6)E
M<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M/F5X=')A
M8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:
M7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M96UB97(@
M=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!0
M05(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I
M;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@
M?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I<F4@4V-A
M;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"
M=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R
M92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R;$E/.CIS
M8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?<V5T7W!A
M<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[
M4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N
M.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%2
M7U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q4
M14U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N
M9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W
M=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U
M<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D
M("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R
M;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%
M32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP87(M(BYU
M;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*)&-A8VAE
M7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L("(\.G)A
M=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE
M(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@D
M9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F
M<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U9CL*<F5A
M9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!E<2`B
M7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA;65?<VEZ
M92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@
M/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L
M;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T
M96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B
M)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M
M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N
M=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N
M86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@
M(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D
M=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@
M)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=
M.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E
M;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M
M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92![
M"FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?
M4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O
M9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P
M<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@
M<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY
M("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II
M9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET
M("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA
M;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92([
M"GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D
M14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R
M;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_
M($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@
M5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[
M7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS
M=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]
M*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,
M25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT[
M"GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6
M>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@
M)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@
M>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U
M<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<
M;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R![
M"G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P
M("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E
M>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O
M<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI
M9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R
M9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S
M<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@
M:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`
M.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@
M:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@
M)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@``0T%#2$4`
M`'!E<FQX<VDN8P````$;`SLP`0``)0```"2,__]$`@``!)#__V@"```TD/__
M3`$``&^0__]P`0``>)'__Z`!``#5D?__X`$``$24__]\`@``^I3__]0"``!Z
ME?__%`,``.N6__]4`P``^YC__Y0#``"(F?__S`,``(>:___\`P``*YO__S0$
M``!YF___6`0``.*;__^`!```Y9O__Y0$``#ZG?__U`0``#.>__\`!0``AI[_
M_SP%``"_G___=`4``!2@__^D!0``4J#__\`%```BHO__\`4``$VB__\4!@``
M'*/__U0&``#WJ?__F`8``$VL___(!@``M*S__TP'``"CN/__D`<``/JX__^T
M!P``,+O__PP(```NO?__'`<``&V___\(`@``<;___QP"``!UO___,`(``'F_
M__],"```%``````````!>E(``7P(`1L,!`2(`0``(````!P```#@CO__.P``
M``!!#@B&`D$.#(,#=\,."$'&#@0`+````$````#WCO__"0$```!!#@B'`D$.
M#(8#00X0@P0"U0K##@Q!Q@X(0<<.!$$+/````'````#0C___70````!!#@B%
M`D$.#(<#00X0A@1!#A2#!4,.&`))"@X40<,.$$'&#@Q!QPX(0<4.!$$+`"0`
M``"P````[8___X0!````00X(A0)!#@R'`T$.$(8$00X4@P5##BP0````V```
M`%V]__\$`````````!````#L````3;W__P0`````````$``````!```]O?__
M!``````````@````%`$``-B)___@`P````X(1@X,2@\+=`1X`#\:.RHR)"(0
M````.`$``)2-__\@`````````%0```!,`0``P)'__[8`````00X(A0)!#@R'
M`T$.$(8$00X4@P5##BP"=`H.%$'##A!!Q@X,0<<."$'%#@1!"VT*#A1!PPX0
M0<8.#$''#@A!Q0X$00L````\````I`$``!Z2__^``````$$."(4"00X,AP-!
M#A"&!$$.%(,%0PX@`F\*#A1!PPX00<8.#$''#@A!Q0X$00L`/````.0!``!>
MDO__<0$```!!#@B%`D$.#(<#00X0A@1!#A2#!48.N`%^"@X40<,.$$'&#@Q!
MQPX(0<4.!$$+`#P````D`@``CY/__Q`"````00X(A0)!#@R'`T$.$(8$00X4
M@P5##CP#%0$*#A1!PPX00<8.#$''#@A!Q0X$00LT````9`(``%^5__^-````
M`$$."(<"00X,A@-!#A"#!$8.F`$"70H.$$'##@Q!Q@X(0<<.!$$+`"P```"<
M`@``M)7___\`````00X(A0)"#05,AP.&!(,%`KD*PT'&0<=!Q0P$!$$+`#0`
M``#,`@``@Y;__Z0`````00X(AP)!#@R&`T$.$(,$1@Z@"`)]"@X00<,.#$'&
M#@A!QPX$00L`(`````0#``#OEO__3@````!!#@B%`D(-!4>#`P)#Q<,,!`0`
M)````"@#```9E___:0````!!#@B%`D(-!4B&`X,$`EO#0<9!Q0P$!!````!0
M`P``6I?__P,`````````/````&0#``!)E___%0(```!!#@B%`D$.#(<#00X0
MA@1!#A2#!48.Q`D">PH.%$'##A!!Q@X,0<<."$'%#@1!"R@```"D`P``'IG_
M_SD`````00X(A@)!#@R#`T,.%'$.#$'##@A!Q@X$````.````-`#```KF?__
M4P````!!#@B&`D$.#(,#0PX0;PH.#$'##@A!Q@X$10M1"@X,0<,."$'&#@1!
M"P``-`````P$``!"F?__.0$```!!#@B'`D$.#(8#00X0@P1##A@#"@$*#A!!
MPPX,0<8."$''#@1!"P`L````1`0``$.:__]5`````$$."(8"00X,@P-##A0"
M2`H.#$'##@A!Q@X$00L````8````=`0``&B:__\^`````$$."(,"0PX4````
M+````)`$``"*FO__T`$```!!#@B%`D(-!4F'`X8$@P4#9`$*PT'&0<=!Q0P$
M!$$+(````,`$```JG/__*P````!!#@B#`D,.#&$*#@A!PPX$00L`/````.0$
M```QG/__SP````!!#@B%`D$.#(<#00X0A@1!#A2#!4,.-`*^"@X40<,.$$'&
M#@Q!QPX(0<4.!$$+`$`````D!0``P)S__]L&````00X(A0)!#@R'`T$.$(8$
M00X4@P5&#K`"`_L""@X40<,.$$'&#@Q!QPX(0<4.!$$+````+````&@%``!7
MH___5@(```!!#@B%`D(-!4F'`X8$@P4#N@$*PT'&0<=!Q0P$!$$+4````)@%
M``!]I?__9P````!!#@B%`D$.#(<#00X0A@1!#A2#!4,.&&4*#A1!PPX00<8.
M#$''#@A!Q0X$00MM#A1!PPX00<8.#$''#@A!Q0X$````+````.P%```*MO__
M/P(```!!#@B%`D(-!4F'`X8$@P4#@P$*PT'&0<=!Q0P$!$$+0````!P&``!@
MI?__[PL```!!#@B%`D$.#(<#00X0A@1!#A2#!48.^`(#UPL*#A1!PPX00<8.
M#$''#@A!Q0X$00L````@````8`8```NQ__]7`````$$."(,"0PX,`E$."$'#
M#@0```!4````A`8``#ZQ__\V`@```$$."(4"00X,AP-!#A"&!$$.%(,%0PX<
M`I(*#A1!PPX00<8.#$''#@A!Q0X$00L"RPH.%$'##A!!Q@X,0<<."$'%#@1!
M"P``/````-P&```<L____@$```!!#@B%`D$.#(<#00X0A@1!#A2#!4,.)`-I
M`0H.%$'##A!!Q@X,0<<."$'%#@1!"Q`````<!P``);?__P0`````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````/____\`````_____P``````
M`````0````$````!````J0(```$```#A`@```0```.\"```!````%0,```\`
M``",!```#````$`2```-````L$4```0```!X`0``!0```/P*```&````G`0`
M``H```#1!```"P```!`````5``````````,`````H````@```.@!```4````
M$0```!<```!0$```$0```-`/```2````@````!,````(````^___;P````CZ
M__]O!```````````````````````````````````````````````````````
M``````````````````````````````````````````````````#LG@``````
M````````````[)X`````````````9A(``'82``"&$@``EA(``*82``"V$@``
MQA(``-82``#F$@``]A(```83```6$P``)A,``#83``!&$P``5A,``&83``!V
M$P``AA,``)83``"F$P``MA,``,83``#6$P``YA,``/83```&%```%A0``"84
M```V%```1A0``%84``!F%```=A0``(84``"6%```IA0``+84``#&%```UA0`
M`.84``#V%```!A4``!85```F%0``-A4``$85``!6%0``9A4``'85``"&%0``
MEA4``*85``"V%0``QA4``-85``#F%0``]A4```86```6%@``)A8``$2A```$
MH0``````````````````````````````````````````````````"E!!4BYP
M;0H`````J$@``$=#0SH@*$YE=$)31"!N8C0@,C`R,#`X,3`I(#<N-2XP`$=#
M0SH@*&YB-"`R,#(P,#@Q,"D@-RXU+C``)$YE=$)31#H@8W)T,"Y3+'8@,2XT
M(#(P,3@O,3$O,C8@,3<Z,S<Z-#4@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T
M,"UC;VUM;VXN8RQV(#$N,C,@,C`Q."\Q,B\R."`R,#HQ,CHS-2!C:')I<W1O
M<R!%>'`@)``D3F5T0E-$.B!C<G1I+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q.#HP
M,3HS,R!J;V5R9R!%>'`@)``D3F5T0E-$.B!C<G1B96=I;BY3+'8@,2XQ(#(P
M,3`O,#@O,#<@,3@Z,#$Z,S,@:F]E<F<@17AP("0`)$YE=$)31#H@8W)T96YD
M+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q.#HP,3HS,R!J;V5R9R!%>'`@)``D3F5T
M0E-$.B!C<G1N+E,L=B`Q+C$@,C`Q,"\P."\P-R`Q.#HP,3HS-"!J;V5R9R!%
M>'`@)`#QSP(`````````````````"`````@````(````"````!L````!````
M```````J*BH@3F\@3&%B96P@4')O=FED960@*BHJ``#QSP(`````````````
M````"`````@````(````"````!L````!```````````J*BH@3F\@3&%B96P@
M4')O=FED960@*BHJ```N<VAS=')T86(`+FEN=&5R<``N;F]T92YN971B<V0N
M:61E;G0`+FYO=&4N;F5T8G-D+G!A>``N:&%S:``N9'EN<WEM`"YD>6YS='(`
M+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S
M`"YJ8W(`+F1Y;F%M:6,`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=``N
M4U5.5U]C=&8`````````````````````````````````````````````````
M``````L````!`````@```#0!```T`0``%P```````````````0`````````3
M````!P````(```!,`0``3`$``!@```````````````0`````````)@````<`
M```"````9`$``&0!```4```````````````$`````````#<````%`````@``
M`'@!``!X`0``)`,```4`````````!`````0````]````"P````(```"<!```
MG`0``&`&```&`````0````0````0````10````,````"````_`H``/P*``#1
M!``````````````!`````````$T````)`````@```-`/``#0#P``@`````4`
M````````!`````@```!6````"0```$(```!0$```4!```.@!```%````%@``
M``0````(````7P````$````&````0!(``$`2```*```````````````0````
M`````%H````!````!@```%`2``!0$@``X`,`````````````$`````0```!E
M`````0````8````P%@``,!8``"````````````````@````(````;@````$`
M```&````4!8``%`6``!9+P`````````````0`````````'0````!````!@``
M`+!%``"P10``"@``````````````$`````````!Z`````0````(```"\10``
MO$4``&Y```````````````0`````````@@````$````"````+(8``"R&```T
M`0`````````````$`````````)`````!`````@```&"'``!@AP``,`<`````
M````````!`````````":`````0````,```#8G@``V(X```@`````````````
M``0`````````H0````$````#````X)X``.".```(```````````````$````
M`````*@````!`````P```.B>``#HC@``!```````````````!`````````"M
M````!@````,```#LG@``[(X``.`````&``````````0````(````:0````$`
M```#````S)\``,R/```T```````````````$````!````+8````!`````P``
M``"@````D`````$`````````````!`````0```"_`````0````,`````H0``
M`)$``#P```````````````0`````````Q0````@````#````0*$``#R1``!$
M``````````````!``````````,H````!````,``````````\D0``.P``````
M`````````0````$````?`````0``````````````=Y$``%4!````````````
M``$`````````TP````$``````````````,R2``"/```````````````$````
L``````$````#``````````````!;DP``W0```````````````0``````````
